{% extends 'cruditor/base.html' %}
{% load i18n %}


{% block container %}
	<div class="container">
		<div class="page-header">
			<h1>
				<i class="glyphicon glyphicon-alert"></i> {% trans 'No access' %}
				<small>{% trans 'Permission to access requested item denied' %}</small>
			</h1>
		</div>
		<p>
			<a href="{{ cruditor.constants.index_url }}" class="btn btn-primary btn-lg">
				{% trans 'Take me to the index page' %}
			</a>
		</p>
	</div>
{% endblock %}
