{% load floppyforms %}
{% block formconfig %}
	{% formconfig row using 'cruditor/forms/row.html' %}
{% endblock %}
{% block forms %}{% for form in forms %}
{% block errors %}
	{% for error in form.non_field_errors %}
		<div class="alert alert-danger">
			{{ error }}
		</div>
	{% endfor %}
	{% for error in form|hidden_field_errors %}
		<div class="alert alert-danger">
			{{ error }}
		</div>
	{% endfor %}
{% endblock errors %}
{% block rows %}
	{% for field in form.visible_fields %}
		{% if forloop.last %}{% formconfig row with hidden_fields=form.hidden_fields %}{% endif %}
		{% block row %}{% formrow field %}{% endblock %}
	{% endfor %}
	{% if not form.visible_fields %}{% for field in form.hidden_fields %}{% formfield field %}{% endfor %}{% endif %}
{% endblock %}
{% endfor %}{% endblock %}
