{% load i18n %}
{% load django_tables2 %}

{% block table.pagination.top %}
	{% if table.page %}
		{% include 'cruditor/includes/pagination.html' %}
	{% endif %}
{% endblock table.pagination.top %}

{% block table %}
<div class="table-responsive">
	<table class="table table-striped" {% if table.attrs %} {{ table.attrs.as_html }}{% endif %}>
		{% block table.thead %}
		<thead>
			<tr>
			{% for column in table.columns %}
				{% if column.orderable %}
				<th {{ column.attrs.th.as_html }}><a href="{% querystring table.prefixed_order_by_field=column.order_by_alias.next %}">{{ column.header }}</a></th>
				{% else %}
				<th {{ column.attrs.th.as_html }}>{{ column.header }}</th>
				{% endif %}
			{% endfor %}
			</tr>
		</thead>
		{% endblock table.thead %}
		{% block table.tbody %}
		<tbody>
			{% for row in table.page.object_list|default:table.rows %}
				{% block table.tbody.row %}
				<tr class="{% cycle 'odd' 'even' %}">
					{% for column, cell in row.items %}
						<td {{ column.attrs.td.as_html }}>{{ cell }}</td>
					{% endfor %}
				</tr>
				{% endblock table.tbody.row %}
			{% empty %}
				{% if table.empty_text %}
					{% block table.tbody.empty_text %}
						<tr><td colspan="{{ table.columns|length }}">{{ table.empty_text }}</td></tr>
					{% endblock table.tbody.empty_text %}
				{% endif %}
			{% endfor %}
		</tbody>
		{% endblock table.tbody %}
		{% block table.tfoot %}
		<tfoot></tfoot>
		{% endblock table.tfoot %}
	</table>
</div>
{% endblock table %}

{% block table.pagination.bottom %}
	{% if table.page %}
		{% include 'cruditor/includes/pagination.html' %}
	{% endif %}
{% endblock table.pagination.bottom %}
